@@ -15,7 +15,7 @@ import hashlib
 import threading
 from copy import deepcopy
 
-from .__init__ import WINDOWS, PY2
+from .__init__ import WINDOWS
 from .util import Pebkac, Queue, fsdec, fsenc, sanitize_fn, ren_open, atomic_move
 
 HAVE_SQLITE3 = False
@@ -291,7 +291,21 @@ class Up2k(object):
 
             if job or wark in reg:
                 job = job or reg[wark]
-                if job["prel"] != cj["prel"] or job["name"] != cj["name"]:
+                if job["prel"] == cj["prel"] and job["name"] == cj["name"]:
+                    # ensure the files haven't been deleted manually
+                    names = [job[x] for x in ["name", "tnam"] if x in job]
+                    for fn in names:
+                        path = os.path.join(job["ptop"], job["prel"], fn)
+                        try:
+                            if os.path.getsize(path) > 0:
+                                # upload completed or both present
+                                break
+                        except:
+                            # missing; restart
+                            job = None
+                            break
+                else:
+                    # file contents match, but not the path
                     src = os.path.join(job["ptop"], job["prel"], job["name"])
                     dst = os.path.join(cj["ptop"], cj["prel"], cj["name"])
                     vsrc = os.path.join(job["vtop"], job["prel"], job["name"])
@@ -335,6 +349,7 @@ class Up2k(object):
                     "name",
                     "size",
                     "lmod",
+                    "poke",
                 ]:
                     job[k] = cj[k]
 
@@ -458,9 +473,8 @@ class Up2k(object):
         db.execute("delete from up where rp = ?", (rp,))
 
     def db_add(self, db, wark, rp, ts, sz):
-        db.execute(
-            "insert into up values (?,?,?,?)", (wark, ts, sz, rp,),
-        )
+        v = (wark, ts, sz, rp)
+        db.execute("insert into up values (?,?,?,?)", v)
 
     def _get_wark(self, cj):
         if len(cj["name"]) > 1024 or len(cj["hash"]) > 512 * 1024:  # 16TiB
@@ -521,6 +535,8 @@ class Up2k(object):
         self.registry[job["ptop"]][job["wark"]] = job
         pdir = os.path.join(job["ptop"], job["prel"])
         job["name"] = self._untaken(pdir, job["name"], job["t0"], job["addr"])
+        # if len(job["name"].split(".")) > 8:
+        #    raise Exception("aaa")
 
         tnam = job["name"] + ".PARTIAL"
         suffix = ".{:.6f}-{}".format(job["t0"], job["addr"])
@@ -545,7 +561,7 @@ class Up2k(object):
 
     def _snapshot(self):
         persist_interval = 30  # persist unfinished uploads index every 30 sec
-        discard_interval = 3600  # drop unfinished uploads after 1 hour inactivity
+        discard_interval = 21600  # drop unfinished uploads after 6 hours inactivity
         prev = {}
         while True:
             time.sleep(persist_interval)
@@ -563,10 +579,15 @@ class Up2k(object):
             for job in rm:
                 del reg[job["wark"]]
                 try:
-                    # remove the placeholder zero-byte file (keep the PARTIAL)
+                    # remove the filename reservation
                     path = os.path.join(job["ptop"], job["prel"], job["name"])
                     if os.path.getsize(path) == 0:
                         os.unlink(path)
+
+                    if len(job["hash"]) == len(job["need"]):
+                        # PARTIAL is empty, delete that too
+                        path = os.path.join(job["ptop"], job["prel"], job["tnam"])
+                        os.unlink(path)
                 except:
                     pass
 
